pynac: A fork of the symbolic computation software GiNaC that uses Python objects
=================================================================================

Description
-----------

A modified version of GiNaC that replaces the dependency on CLN by
Python.

License
-------

GPL V2+


Upstream Contact
----------------

-  https://github.com/pynac/pynac
-  http://pynac.org
-  Burcin Erocal - burcin spam.erocal.org
-  William Stein - wstein spam.gmail.com
-  Mike Hansen - mhansen spam.gmail.com

Dependencies
------------

Python
